@@ -14,12 +14,12 @@ library(i2extras)
 
 ## ----bootstrap----------------------------------------------------------------
 dat <- fluH7N9_china_2013
-x <- incidence(dat, date_index = date_of_onset, groups = gender)
+x <- incidence(dat, date_index = "date_of_onset", groups = "gender")
 bootstrap(x)
 
 ## ----findpeak-----------------------------------------------------------------
 dat <- fluH7N9_china_2013
-x <- incidence(dat, date_index = date_of_onset, groups = gender)
+x <- incidence(dat, date_index = "date_of_onset", groups = "gender")
 
 # peaks across each group
 find_peak(x)
@@ -29,11 +29,11 @@ find_peak(regroup(x))
 
 ## ----estimatepeak-------------------------------------------------------------
 dat <- fluH7N9_china_2013
-x <- incidence(dat, date_index = date_of_onset, groups = province)
+x <- incidence(dat, date_index = "date_of_onset", groups = "province")
 
-# regrouping for overall peak
-estimate_peak(regroup(x))
+# regrouping for overall peak (we suspend progress bar for markdown)
+estimate_peak(regroup(x), progress = FALSE)
 
-# across provinces and with progress bar suppressed
+# across provinces
 estimate_peak(x, progress = FALSE)
 
